use lazy_static::lazy_static;
use std::collections::HashMap;

#[derive(Copy, Clone, Debug)]
pub struct DMC {
    pub number: &'static str,
    pub name: &'static str,
    pub color: (f64, f64, f64),
}

pub const COLORS: &[DMC] = &[
    DMC {
        number: "3713",
        name: "Salmon Very Light",
        color: (1.0, 0.886, 0.886),
    },
    DMC {
        number: "761",
        name: "Salmon Light",
        color: (1.0, 0.788, 0.788),
    },
    DMC {
        number: "760",
        name: "Salmon",
        color: (0.961, 0.678, 0.678),
    },
    DMC {
        number: "3712",
        name: "Salmon Medium",
        color: (0.945, 0.529, 0.529),
    },
    DMC {
        number: "3328",
        name: "Salmon Dark",
        color: (0.89, 0.427, 0.427),
    },
    DMC {
        number: "347",
        name: "Salmon Very Dark",
        color: (0.749, 0.176, 0.176),
    },
    DMC {
        number: "353",
        name: "Peach",
        color: (0.996, 0.843, 0.8),
    },
    DMC {
        number: "352",
        name: "Coral Light",
        color: (0.992, 0.612, 0.592),
    },
    DMC {
        number: "351",
        name: "Coral",
        color: (0.914, 0.416, 0.404),
    },
    DMC {
        number: "350",
        name: "Coral Medium",
        color: (0.878, 0.282, 0.282),
    },
    DMC {
        number: "349",
        name: "Coral Dark",
        color: (0.824, 0.0627, 0.208),
    },
    DMC {
        number: "817",
        name: "Coral Red Very Dark",
        color: (0.733, 0.0196, 0.122),
    },
    DMC {
        number: "3708",
        name: "Melon Light",
        color: (1.0, 0.796, 0.835),
    },
    DMC {
        number: "3706",
        name: "Melon Medium",
        color: (1.0, 0.678, 0.737),
    },
    DMC {
        number: "3705",
        name: "Melon Dark",
        color: (1.0, 0.475, 0.573),
    },
    DMC {
        number: "3801",
        name: "Melon Very Dark",
        color: (0.906, 0.286, 0.404),
    },
    DMC {
        number: "666",
        name: "Bright Red",
        color: (0.89, 0.114, 0.259),
    },
    DMC {
        number: "321",
        name: "Red",
        color: (0.78, 0.169, 0.231),
    },
    DMC {
        number: "304",
        name: "Red Medium",
        color: (0.718, 0.122, 0.2),
    },
    DMC {
        number: "498",
        name: "Red Dark",
        color: (0.655, 0.0745, 0.169),
    },
    DMC {
        number: "816",
        name: "Garnet",
        color: (0.592, 0.0431, 0.137),
    },
    DMC {
        number: "815",
        name: "Garnet Medium",
        color: (0.529, 0.0275, 0.122),
    },
    DMC {
        number: "814",
        name: "Garnet Dark",
        color: (0.482, 0.0, 0.106),
    },
    DMC {
        number: "894",
        name: "Carnation Very Light",
        color: (1.0, 0.698, 0.733),
    },
    DMC {
        number: "893",
        name: "Carnation Light",
        color: (0.988, 0.565, 0.635),
    },
    DMC {
        number: "892",
        name: "Carnation Medium",
        color: (1.0, 0.475, 0.549),
    },
    DMC {
        number: "891",
        name: "Carnation Dark",
        color: (1.0, 0.341, 0.451),
    },
    DMC {
        number: "818",
        name: "Baby Pink",
        color: (1.0, 0.875, 0.851),
    },
    DMC {
        number: "957",
        name: "Geranium Pale",
        color: (0.992, 0.71, 0.71),
    },
    DMC {
        number: "956",
        name: "Geranium",
        color: (1.0, 0.569, 0.569),
    },
    DMC {
        number: "309",
        name: "Rose Dark",
        color: (0.729, 0.29, 0.29),
    },
    DMC {
        number: "963",
        name: "Dusty Rose Ultra Very Light",
        color: (1.0, 0.843, 0.843),
    },
    DMC {
        number: "3716",
        name: "Dusty Rose Medium Very Light",
        color: (1.0, 0.741, 0.741),
    },
    DMC {
        number: "962",
        name: "Dusty Rose Medium",
        color: (0.902, 0.541, 0.541),
    },
    DMC {
        number: "961",
        name: "Dusty Rose Dark",
        color: (0.812, 0.451, 0.451),
    },
    DMC {
        number: "3833",
        name: "Raspberry Light",
        color: (0.918, 0.525, 0.6),
    },
    DMC {
        number: "3832",
        name: "Raspberry Medium",
        color: (0.859, 0.333, 0.431),
    },
    DMC {
        number: "3831",
        name: "Raspberry Dark",
        color: (0.702, 0.184, 0.282),
    },
    DMC {
        number: "777",
        name: "Raspberry Very Dark",
        color: (0.569, 0.208, 0.275),
    },
    DMC {
        number: "819",
        name: "Baby Pink Light",
        color: (1.0, 0.933, 0.922),
    },
    DMC {
        number: "3326",
        name: "Rose Light",
        color: (0.984, 0.678, 0.706),
    },
    DMC {
        number: "776",
        name: "Pink Medium",
        color: (0.988, 0.69, 0.725),
    },
    DMC {
        number: "899",
        name: "Rose Medium",
        color: (0.949, 0.463, 0.533),
    },
    DMC {
        number: "335",
        name: "Rose",
        color: (0.933, 0.329, 0.431),
    },
    DMC {
        number: "326",
        name: "Rose Very Dark",
        color: (0.702, 0.231, 0.294),
    },
    DMC {
        number: "151",
        name: "Dusty Rose Very Light",
        color: (0.941, 0.808, 0.831),
    },
    DMC {
        number: "3354",
        name: "Dusty Rose Light",
        color: (0.894, 0.651, 0.675),
    },
    DMC {
        number: "3733",
        name: "Dusty Rose",
        color: (0.91, 0.529, 0.608),
    },
    DMC {
        number: "3731",
        name: "Dusty Rose Very Dark",
        color: (0.855, 0.404, 0.514),
    },
    DMC {
        number: "3350",
        name: "Dusty Rose Ultra Dark",
        color: (0.737, 0.263, 0.396),
    },
    DMC {
        number: "150",
        name: "Dusty Rose Ultra Very Dark",
        color: (0.671, 0.00784, 0.286),
    },
    DMC {
        number: "3689",
        name: "Mauve Light",
        color: (0.984, 0.749, 0.761),
    },
    DMC {
        number: "3688",
        name: "Mauve Medium",
        color: (0.906, 0.663, 0.675),
    },
    DMC {
        number: "3687",
        name: "Mauve",
        color: (0.788, 0.42, 0.439),
    },
    DMC {
        number: "3803",
        name: "Mauve Dark",
        color: (0.671, 0.2, 0.341),
    },
    DMC {
        number: "3685",
        name: "Mauve Very Dark",
        color: (0.533, 0.0824, 0.192),
    },
    DMC {
        number: "605",
        name: "Cranberry Very Light",
        color: (1.0, 0.753, 0.804),
    },
    DMC {
        number: "604",
        name: "Cranberry Light",
        color: (1.0, 0.69, 0.745),
    },
    DMC {
        number: "603",
        name: "Cranberry",
        color: (1.0, 0.643, 0.745),
    },
    DMC {
        number: "602",
        name: "Cranberry Medium",
        color: (0.886, 0.282, 0.455),
    },
    DMC {
        number: "601",
        name: "Cranberry Dark",
        color: (0.82, 0.157, 0.416),
    },
    DMC {
        number: "600",
        name: "Cranberry Very Dark",
        color: (0.804, 0.184, 0.388),
    },
    DMC {
        number: "3806",
        name: "Cyclamen Pink Light",
        color: (1.0, 0.549, 0.682),
    },
    DMC {
        number: "3805",
        name: "Cyclamen Pink",
        color: (0.953, 0.278, 0.545),
    },
    DMC {
        number: "3804",
        name: "Cyclamen Pink Dark",
        color: (0.878, 0.157, 0.463),
    },
    DMC {
        number: "3609",
        name: "Plum Ultra Light",
        color: (0.957, 0.682, 0.843),
    },
    DMC {
        number: "3608",
        name: "Plum Very Light",
        color: (0.918, 0.612, 0.769),
    },
    DMC {
        number: "3607",
        name: "Plum Light",
        color: (0.773, 0.286, 0.537),
    },
    DMC {
        number: "718",
        name: "Plum",
        color: (0.612, 0.141, 0.384),
    },
    DMC {
        number: "917",
        name: "Plum Medium",
        color: (0.608, 0.0745, 0.349),
    },
    DMC {
        number: "915",
        name: "Plum Dark",
        color: (0.51, 0.0, 0.263),
    },
    DMC {
        number: "225",
        name: "Shell Pink Ultra Very Light",
        color: (1.0, 0.875, 0.843),
    },
    DMC {
        number: "224",
        name: "Shell Pink Very Light",
        color: (0.922, 0.718, 0.686),
    },
    DMC {
        number: "152",
        name: "Shell Pink Medium Light",
        color: (0.886, 0.627, 0.6),
    },
    DMC {
        number: "223",
        name: "Shell Pink Light",
        color: (0.8, 0.518, 0.486),
    },
    DMC {
        number: "3722",
        name: "Shell Pink Medium",
        color: (0.737, 0.424, 0.392),
    },
    DMC {
        number: "3721",
        name: "Shell Pink Dark",
        color: (0.631, 0.294, 0.318),
    },
    DMC {
        number: "221",
        name: "Shell Pink Very Dark",
        color: (0.533, 0.243, 0.263),
    },
    DMC {
        number: "778",
        name: "Antique Mauve Very Light",
        color: (0.875, 0.702, 0.733),
    },
    DMC {
        number: "3727",
        name: "Antique Mauve Light",
        color: (0.859, 0.663, 0.698),
    },
    DMC {
        number: "316",
        name: "Antique Mauve Medium",
        color: (0.718, 0.451, 0.498),
    },
    DMC {
        number: "3726",
        name: "Antique Mauve Dark",
        color: (0.608, 0.357, 0.4),
    },
    DMC {
        number: "315",
        name: "Antique Mauve Medium Dark",
        color: (0.506, 0.286, 0.322),
    },
    DMC {
        number: "3802",
        name: "Antique Mauve Very Darkv",
        color: (0.443, 0.255, 0.286),
    },
    DMC {
        number: "902",
        name: "Garnet Very Dark",
        color: (0.51, 0.149, 0.216),
    },
    DMC {
        number: "3743",
        name: "Antique Violet Very Light",
        color: (0.843, 0.796, 0.827),
    },
    DMC {
        number: "3042",
        name: "Antique Violet Light",
        color: (0.718, 0.616, 0.655),
    },
    DMC {
        number: "3041",
        name: "Antique Violet Medium",
        color: (0.584, 0.435, 0.486),
    },
    DMC {
        number: "3740",
        name: "Antique Violet Dark",
        color: (0.471, 0.341, 0.384),
    },
    DMC {
        number: "3836",
        name: "Grape Light",
        color: (0.729, 0.569, 0.667),
    },
    DMC {
        number: "3835",
        name: "Grape Medium",
        color: (0.58, 0.376, 0.514),
    },
    DMC {
        number: "3834",
        name: "Grape Dark",
        color: (0.447, 0.216, 0.365),
    },
    DMC {
        number: "154",
        name: "Grape Very Dark",
        color: (0.341, 0.141, 0.2),
    },
    DMC {
        number: "211",
        name: "Lavender Light",
        color: (0.89, 0.796, 0.89),
    },
    DMC {
        number: "210",
        name: "Lavender Medium",
        color: (0.824, 0.624, 0.765),
    },
    DMC {
        number: "209",
        name: "Lavender Dark",
        color: (0.639, 0.482, 0.655),
    },
    DMC {
        number: "208",
        name: "Lavender Very Dark",
        color: (0.514, 0.357, 0.545),
    },
    DMC {
        number: "3837",
        name: "Lavender Ultra Dark",
        color: (0.424, 0.227, 0.431),
    },
    DMC {
        number: "327",
        name: "Violet Dark",
        color: (0.388, 0.212, 0.4),
    },
    DMC {
        number: "153",
        name: "Violet Very Light",
        color: (0.902, 0.8, 0.851),
    },
    DMC {
        number: "554",
        name: "Violet Light",
        color: (0.859, 0.702, 0.796),
    },
    DMC {
        number: "553",
        name: "Violet",
        color: (0.639, 0.388, 0.545),
    },
    DMC {
        number: "552",
        name: "Violet  Medium",
        color: (0.502, 0.227, 0.42),
    },
    DMC {
        number: "550",
        name: "Violet Very Dark",
        color: (0.361, 0.0941, 0.306),
    },
    DMC {
        number: "3747",
        name: "Blue Violet Very Light",
        color: (0.827, 0.843, 0.929),
    },
    DMC {
        number: "341",
        name: "Blue Violet Light",
        color: (0.718, 0.749, 0.867),
    },
    DMC {
        number: "156",
        name: "Blue Violet Medium Light",
        color: (0.639, 0.682, 0.82),
    },
    DMC {
        number: "340",
        name: "Blue Violet Medium",
        color: (0.678, 0.655, 0.78),
    },
    DMC {
        number: "155",
        name: "Blue Violet Medium Dark",
        color: (0.596, 0.569, 0.714),
    },
    DMC {
        number: "3746",
        name: "Blue Violet Dark",
        color: (0.467, 0.42, 0.596),
    },
    DMC {
        number: "333",
        name: "Blue Violet Very Dark",
        color: (0.361, 0.329, 0.471),
    },
    DMC {
        number: "157",
        name: "Cornflower Blue Very Light",
        color: (0.733, 0.765, 0.851),
    },
    DMC {
        number: "794",
        name: "Cornflower Blue Light",
        color: (0.561, 0.612, 0.757),
    },
    DMC {
        number: "793",
        name: "Cornflower Blue Medium",
        color: (0.439, 0.49, 0.635),
    },
    DMC {
        number: "3807",
        name: "Cornflower Blue",
        color: (0.376, 0.404, 0.549),
    },
    DMC {
        number: "792",
        name: "Cornflower Blue Dark",
        color: (0.333, 0.357, 0.482),
    },
    DMC {
        number: "158",
        name: "Cornflower Blue  Very Dark",
        color: (0.298, 0.322, 0.431),
    },
    DMC {
        number: "791",
        name: "Cornflower Blue Very Dark",
        color: (0.275, 0.271, 0.388),
    },
    DMC {
        number: "3840",
        name: "Lavender Blue Light",
        color: (0.69, 0.753, 0.855),
    },
    DMC {
        number: "3839",
        name: "Lavender Blue Medium",
        color: (0.482, 0.557, 0.671),
    },
    DMC {
        number: "3838",
        name: "Lavender Blue Dark",
        color: (0.361, 0.447, 0.58),
    },
    DMC {
        number: "800",
        name: "Delft Blue Pale",
        color: (0.753, 0.8, 0.871),
    },
    DMC {
        number: "809",
        name: "Delft Blue",
        color: (0.58, 0.659, 0.776),
    },
    DMC {
        number: "799",
        name: "Delft Blue Medium",
        color: (0.455, 0.557, 0.714),
    },
    DMC {
        number: "798",
        name: "Delft Blue Dark",
        color: (0.275, 0.416, 0.557),
    },
    DMC {
        number: "797",
        name: "Royal Blue",
        color: (0.0745, 0.278, 0.49),
    },
    DMC {
        number: "796",
        name: "Royal Blue Dark",
        color: (0.0667, 0.255, 0.427),
    },
    DMC {
        number: "820",
        name: "Royal Blue Very Dark",
        color: (0.0549, 0.212, 0.361),
    },
    DMC {
        number: "162",
        name: "Blue Ultra Very Light",
        color: (0.859, 0.925, 0.961),
    },
    DMC {
        number: "827",
        name: "Blue Very Light",
        color: (0.741, 0.867, 0.929),
    },
    DMC {
        number: "813",
        name: "Blue Light",
        color: (0.631, 0.761, 0.843),
    },
    DMC {
        number: "826",
        name: "Blue Medium",
        color: (0.42, 0.62, 0.749),
    },
    DMC {
        number: "825",
        name: "Blue Dark",
        color: (0.278, 0.506, 0.647),
    },
    DMC {
        number: "824",
        name: "Blue Very Dark",
        color: (0.224, 0.412, 0.529),
    },
    DMC {
        number: "996",
        name: "Electric Blue Medium",
        color: (0.188, 0.761, 0.925),
    },
    DMC {
        number: "3843",
        name: "Electric Blue",
        color: (0.0784, 0.667, 0.816),
    },
    DMC {
        number: "995",
        name: "Electric Blue Dark",
        color: (0.149, 0.588, 0.714),
    },
    DMC {
        number: "3846",
        name: "Turquoise Bright Light",
        color: (0.0235, 0.89, 0.902),
    },
    DMC {
        number: "3845",
        name: "Turquoise Bright Medium",
        color: (0.0157, 0.769, 0.792),
    },
    DMC {
        number: "3844",
        name: "Turquoise Bright Dark",
        color: (0.0706, 0.682, 0.729),
    },
    DMC {
        number: "159",
        name: "Blue Gray Light",
        color: (0.78, 0.792, 0.843),
    },
    DMC {
        number: "160",
        name: "Blue Gray Medium",
        color: (0.6, 0.624, 0.718),
    },
    DMC {
        number: "161",
        name: "Blue Gray",
        color: (0.471, 0.502, 0.643),
    },
    DMC {
        number: "3756",
        name: "Baby Blue Ultra Very Light",
        color: (0.933, 0.988, 0.988),
    },
    DMC {
        number: "775",
        name: "Baby Blue Very Light",
        color: (0.851, 0.922, 0.945),
    },
    DMC {
        number: "3841",
        name: "Baby Blue Pale",
        color: (0.804, 0.875, 0.929),
    },
    DMC {
        number: "3325",
        name: "Baby Blue Light",
        color: (0.722, 0.824, 0.902),
    },
    DMC {
        number: "3755",
        name: "Baby Blue",
        color: (0.573, 0.706, 0.808),
    },
    DMC {
        number: "334",
        name: "Baby Blue Medium",
        color: (0.451, 0.624, 0.757),
    },
    DMC {
        number: "322",
        name: "Baby Blue Dark",
        color: (0.353, 0.561, 0.722),
    },
    DMC {
        number: "312",
        name: "Baby Blue Very Dark",
        color: (0.208, 0.4, 0.545),
    },
    DMC {
        number: "803",
        name: "Baby Blue Ultra Very Dark",
        color: (0.173, 0.349, 0.486),
    },
    DMC {
        number: "336",
        name: "Navy Blue",
        color: (0.145, 0.231, 0.451),
    },
    DMC {
        number: "823",
        name: "Navy Blue Dark",
        color: (0.129, 0.188, 0.388),
    },
    DMC {
        number: "939",
        name: "Navy Blue Very Dark",
        color: (0.106, 0.157, 0.325),
    },
    DMC {
        number: "3753",
        name: "Antique Blue Ultra Very Light",
        color: (0.859, 0.886, 0.914),
    },
    DMC {
        number: "3752",
        name: "Antique Blue Very Light",
        color: (0.78, 0.82, 0.859),
    },
    DMC {
        number: "932",
        name: "Antique Blue Light",
        color: (0.635, 0.71, 0.776),
    },
    DMC {
        number: "931",
        name: "Antique Blue Medium",
        color: (0.416, 0.522, 0.62),
    },
    DMC {
        number: "930",
        name: "Antique Blue Dark",
        color: (0.271, 0.361, 0.443),
    },
    DMC {
        number: "3750",
        name: "Antique Blue Very Dark",
        color: (0.22, 0.298, 0.369),
    },
    DMC {
        number: "828",
        name: "Sky Blue Very Light",
        color: (0.773, 0.91, 0.929),
    },
    DMC {
        number: "3761",
        name: "Sky Blue Light",
        color: (0.675, 0.847, 0.886),
    },
    DMC {
        number: "519",
        name: "Sky Blue",
        color: (0.494, 0.694, 0.784),
    },
    DMC {
        number: "518",
        name: "Wedgewood Light",
        color: (0.31, 0.576, 0.655),
    },
    DMC {
        number: "3760",
        name: "Wedgewood Medium",
        color: (0.243, 0.522, 0.635),
    },
    DMC {
        number: "517",
        name: "Wedgewood Dark",
        color: (0.231, 0.463, 0.561),
    },
    DMC {
        number: "3842",
        name: "Wedgewood Very Dark",
        color: (0.196, 0.4, 0.486),
    },
    DMC {
        number: "311",
        name: "Wedgewood Ultra Very Dark",
        color: (0.11, 0.314, 0.4),
    },
    DMC {
        number: "747",
        name: "Peacock Blue Very Light",
        color: (0.898, 0.988, 0.992),
    },
    DMC {
        number: "3766",
        name: "Peacock Blue Light",
        color: (0.6, 0.812, 0.851),
    },
    DMC {
        number: "807",
        name: "Peacock Blue",
        color: (0.392, 0.671, 0.729),
    },
    DMC {
        number: "806",
        name: "Peacock Blue Dark",
        color: (0.239, 0.584, 0.647),
    },
    DMC {
        number: "3765",
        name: "Peacock Blue Very Dark",
        color: (0.204, 0.498, 0.549),
    },
    DMC {
        number: "3811",
        name: "Turquoise Very Light",
        color: (0.737, 0.89, 0.902),
    },
    DMC {
        number: "598",
        name: "Turquoise Light",
        color: (0.565, 0.765, 0.8),
    },
    DMC {
        number: "597",
        name: "Turquoise",
        color: (0.357, 0.639, 0.702),
    },
    DMC {
        number: "3810",
        name: "Turquoise Dark",
        color: (0.282, 0.557, 0.604),
    },
    DMC {
        number: "3809",
        name: "Turquoise Vy Dark",
        color: (0.247, 0.486, 0.522),
    },
    DMC {
        number: "3808",
        name: "Turquoise Ultra Very Dark",
        color: (0.212, 0.412, 0.439),
    },
    DMC {
        number: "928",
        name: "Gray Green Very Light",
        color: (0.867, 0.89, 0.89),
    },
    DMC {
        number: "927",
        name: "Gray Green Light",
        color: (0.741, 0.796, 0.796),
    },
    DMC {
        number: "926",
        name: "Gray Green Medium",
        color: (0.596, 0.682, 0.682),
    },
    DMC {
        number: "3768",
        name: "Gray Green Dark",
        color: (0.396, 0.498, 0.498),
    },
    DMC {
        number: "924",
        name: "Gray Green Vy Dark",
        color: (0.337, 0.416, 0.416),
    },
    DMC {
        number: "3849",
        name: "Teal Green Light",
        color: (0.322, 0.702, 0.682),
    },
    DMC {
        number: "3848",
        name: "Teal Green Medium",
        color: (0.255, 0.576, 0.573),
    },
    DMC {
        number: "3847",
        name: "Teal Green Dark",
        color: (0.204, 0.49, 0.459),
    },
    DMC {
        number: "964",
        name: "Sea Green Light",
        color: (0.663, 0.886, 0.847),
    },
    DMC {
        number: "959",
        name: "Sea Green Medium",
        color: (0.349, 0.78, 0.706),
    },
    DMC {
        number: "958",
        name: "Sea Green Dark",
        color: (0.243, 0.714, 0.631),
    },
    DMC {
        number: "3812",
        name: "Sea Green Very Dark",
        color: (0.184, 0.549, 0.518),
    },
    DMC {
        number: "3851",
        name: "Green Bright Light",
        color: (0.286, 0.702, 0.631),
    },
    DMC {
        number: "943",
        name: "Green Bright Medium",
        color: (0.239, 0.576, 0.518),
    },
    DMC {
        number: "3850",
        name: "Green Bright Dark",
        color: (0.216, 0.518, 0.467),
    },
    DMC {
        number: "993",
        name: "Aquamarine Very Light",
        color: (0.565, 0.753, 0.706),
    },
    DMC {
        number: "992",
        name: "Aquamarine Light",
        color: (0.435, 0.682, 0.624),
    },
    DMC {
        number: "3814",
        name: "Aquamarine",
        color: (0.314, 0.545, 0.49),
    },
    DMC {
        number: "991",
        name: "Aquamarine Dark",
        color: (0.278, 0.482, 0.431),
    },
    DMC {
        number: "966",
        name: "Jade Ultra Very Light",
        color: (0.725, 0.843, 0.753),
    },
    DMC {
        number: "564",
        name: "Jade Very Light",
        color: (0.655, 0.804, 0.686),
    },
    DMC {
        number: "563",
        name: "Jade Light",
        color: (0.561, 0.753, 0.596),
    },
    DMC {
        number: "562",
        name: "Jade Medium",
        color: (0.325, 0.592, 0.416),
    },
    DMC {
        number: "505",
        name: "Jade Green",
        color: (0.2, 0.514, 0.384),
    },
    DMC {
        number: "3817",
        name: "Celadon Green Light",
        color: (0.6, 0.765, 0.667),
    },
    DMC {
        number: "3816",
        name: "Celadon Green",
        color: (0.396, 0.647, 0.49),
    },
    DMC {
        number: "163",
        name: "Celadon Green Medium",
        color: (0.302, 0.514, 0.38),
    },
    DMC {
        number: "3815",
        name: "Celadon Green Dark",
        color: (0.278, 0.467, 0.349),
    },
    DMC {
        number: "561",
        name: "Celadon Green VD",
        color: (0.173, 0.416, 0.271),
    },
    DMC {
        number: "504",
        name: "Blue Green Very Light",
        color: (0.769, 0.871, 0.8),
    },
    DMC {
        number: "3813",
        name: "Blue Green Light",
        color: (0.698, 0.831, 0.741),
    },
    DMC {
        number: "503",
        name: "Blue Green Medium",
        color: (0.482, 0.675, 0.58),
    },
    DMC {
        number: "502",
        name: "Blue Green",
        color: (0.357, 0.565, 0.443),
    },
    DMC {
        number: "501",
        name: "Blue Green Dark",
        color: (0.224, 0.435, 0.322),
    },
    DMC {
        number: "500",
        name: "Blue Green Very Dark",
        color: (0.0157, 0.302, 0.2),
    },
    DMC {
        number: "955",
        name: "Nile Green Light",
        color: (0.635, 0.839, 0.678),
    },
    DMC {
        number: "954",
        name: "Nile Green",
        color: (0.533, 0.729, 0.569),
    },
    DMC {
        number: "913",
        name: "Nile Green Medium",
        color: (0.427, 0.671, 0.467),
    },
    DMC {
        number: "912",
        name: "Emerald Green Light",
        color: (0.106, 0.616, 0.42),
    },
    DMC {
        number: "911",
        name: "Emerald Green Medium",
        color: (0.0941, 0.565, 0.396),
    },
    DMC {
        number: "910",
        name: "Emerald Green Dark",
        color: (0.0941, 0.494, 0.337),
    },
    DMC {
        number: "909",
        name: "Emerald Green Very Dark",
        color: (0.0824, 0.435, 0.286),
    },
    DMC {
        number: "3818",
        name: "Emerald Green Ultra Very Dark",
        color: (0.0667, 0.353, 0.231),
    },
    DMC {
        number: "369",
        name: "Pistachio Green Very Light",
        color: (0.843, 0.929, 0.8),
    },
    DMC {
        number: "368",
        name: "Pistachio Green Light",
        color: (0.651, 0.761, 0.596),
    },
    DMC {
        number: "320",
        name: "Pistachio Green Medium",
        color: (0.412, 0.533, 0.353),
    },
    DMC {
        number: "367",
        name: "Pistachio Green Dark",
        color: (0.38, 0.478, 0.322),
    },
    DMC {
        number: "319",
        name: "Pistachio Grn Very Dark",
        color: (0.125, 0.373, 0.18),
    },
    DMC {
        number: "890",
        name: "Pistachio Grn Ultra Very Dark",
        color: (0.0941, 0.286, 0.137),
    },
    DMC {
        number: "164",
        name: "Forest Green Light",
        color: (0.784, 0.847, 0.722),
    },
    DMC {
        number: "989",
        name: "Forest Green ",
        color: (0.553, 0.651, 0.459),
    },
    DMC {
        number: "988",
        name: "Forest Green Medium",
        color: (0.451, 0.545, 0.357),
    },
    DMC {
        number: "987",
        name: "Forest Green Dark",
        color: (0.345, 0.443, 0.255),
    },
    DMC {
        number: "986",
        name: "Forest Green Very Dark",
        color: (0.251, 0.322, 0.188),
    },
    DMC {
        number: "772",
        name: "Yellow Green Very Light",
        color: (0.894, 0.925, 0.831),
    },
    DMC {
        number: "3348",
        name: "Yellow Green Light",
        color: (0.8, 0.851, 0.694),
    },
    DMC {
        number: "3347",
        name: "Yellow Green Medium",
        color: (0.443, 0.576, 0.361),
    },
    DMC {
        number: "3346",
        name: "Hunter Green",
        color: (0.251, 0.416, 0.227),
    },
    DMC {
        number: "3345",
        name: "Hunter Green Dark",
        color: (0.106, 0.349, 0.0824),
    },
    DMC {
        number: "895",
        name: "Hunter Green Very Dark",
        color: (0.106, 0.325, 0.0),
    },
    DMC {
        number: "704",
        name: "Chartreuse Bright",
        color: (0.62, 0.812, 0.204),
    },
    DMC {
        number: "703",
        name: "Chartreuse",
        color: (0.482, 0.71, 0.278),
    },
    DMC {
        number: "702",
        name: "Kelly Green",
        color: (0.278, 0.655, 0.184),
    },
    DMC {
        number: "701",
        name: "Green Light",
        color: (0.247, 0.561, 0.161),
    },
    DMC {
        number: "700",
        name: "Green Bright",
        color: (0.0275, 0.451, 0.106),
    },
    DMC {
        number: "699",
        name: "Green",
        color: (0.0196, 0.396, 0.0902),
    },
    DMC {
        number: "907",
        name: "Parrot Green Light",
        color: (0.78, 0.902, 0.4),
    },
    DMC {
        number: "906",
        name: "Parrot Green Medium",
        color: (0.498, 0.702, 0.208),
    },
    DMC {
        number: "905",
        name: "Parrot Green Dark",
        color: (0.384, 0.541, 0.157),
    },
    DMC {
        number: "904",
        name: "Parrot Green Very Dark",
        color: (0.333, 0.471, 0.133),
    },
    DMC {
        number: "472",
        name: "Avocado Green Ultra Light",
        color: (0.847, 0.894, 0.596),
    },
    DMC {
        number: "471",
        name: "Avocado Grn Very Light",
        color: (0.682, 0.749, 0.475),
    },
    DMC {
        number: "470",
        name: "Avocado Grn Light",
        color: (0.58, 0.671, 0.31),
    },
    DMC {
        number: "469",
        name: "Avocado Green",
        color: (0.447, 0.518, 0.235),
    },
    DMC {
        number: "937",
        name: "Avocado Green Medium",
        color: (0.384, 0.443, 0.2),
    },
    DMC {
        number: "936",
        name: "Avocado Green Very Dark",
        color: (0.298, 0.345, 0.149),
    },
    DMC {
        number: "935",
        name: "Avocado Green Dark",
        color: (0.259, 0.302, 0.129),
    },
    DMC {
        number: "934",
        name: "Avocado Grn Black",
        color: (0.192, 0.224, 0.098),
    },
    DMC {
        number: "523",
        name: "Fern Green Light",
        color: (0.671, 0.694, 0.592),
    },
    DMC {
        number: "3053",
        name: "Green Gray",
        color: (0.612, 0.643, 0.51),
    },
    DMC {
        number: "3052",
        name: "Green Gray Medium",
        color: (0.533, 0.573, 0.408),
    },
    DMC {
        number: "3051",
        name: "Green Gray Dark",
        color: (0.373, 0.4, 0.282),
    },
    DMC {
        number: "524",
        name: "Fern Green Very Light",
        color: (0.769, 0.804, 0.675),
    },
    DMC {
        number: "522",
        name: "Fern Green",
        color: (0.588, 0.62, 0.494),
    },
    DMC {
        number: "520",
        name: "Fern Green Dark",
        color: (0.4, 0.427, 0.31),
    },
    DMC {
        number: "3364",
        name: "Pine Green",
        color: (0.514, 0.592, 0.373),
    },
    DMC {
        number: "3363",
        name: "Pine Green Medium",
        color: (0.447, 0.51, 0.337),
    },
    DMC {
        number: "3362",
        name: "Pine Green Dark",
        color: (0.369, 0.42, 0.278),
    },
    DMC {
        number: "165",
        name: "Moss Green Very Light",
        color: (0.937, 0.957, 0.643),
    },
    DMC {
        number: "3819",
        name: "Moss Green Light",
        color: (0.878, 0.91, 0.408),
    },
    DMC {
        number: "166",
        name: "Moss Green Medium Light",
        color: (0.753, 0.784, 0.251),
    },
    DMC {
        number: "581",
        name: "Moss Green",
        color: (0.655, 0.682, 0.22),
    },
    DMC {
        number: "580",
        name: "Moss Green Dark",
        color: (0.533, 0.553, 0.2),
    },
    DMC {
        number: "734",
        name: "Olive Green Light",
        color: (0.78, 0.753, 0.467),
    },
    DMC {
        number: "733",
        name: "Olive Green Medium",
        color: (0.737, 0.702, 0.298),
    },
    DMC {
        number: "732",
        name: "Olive Green",
        color: (0.58, 0.549, 0.212),
    },
    DMC {
        number: "731",
        name: "Olive Green Dark",
        color: (0.576, 0.545, 0.216),
    },
    DMC {
        number: "730",
        name: "Olive Green Very Dark",
        color: (0.51, 0.482, 0.188),
    },
    DMC {
        number: "3013",
        name: "Khaki Green Light",
        color: (0.725, 0.725, 0.51),
    },
    DMC {
        number: "3012",
        name: "Khaki Green Medium",
        color: (0.651, 0.655, 0.365),
    },
    DMC {
        number: "3011",
        name: "Khaki Green Dark",
        color: (0.537, 0.541, 0.345),
    },
    DMC {
        number: "372",
        name: "Mustard Light",
        color: (0.8, 0.718, 0.518),
    },
    DMC {
        number: "371",
        name: "Mustard",
        color: (0.749, 0.651, 0.443),
    },
    DMC {
        number: "370",
        name: "Mustard Medium",
        color: (0.722, 0.616, 0.392),
    },
    DMC {
        number: "834",
        name: "Golden Olive Very Light",
        color: (0.859, 0.745, 0.498),
    },
    DMC {
        number: "833",
        name: "Golden Olive Light",
        color: (0.784, 0.671, 0.424),
    },
    DMC {
        number: "832",
        name: "Golden Olive",
        color: (0.741, 0.608, 0.318),
    },
    DMC {
        number: "831",
        name: "Golden Olive Medium",
        color: (0.667, 0.561, 0.337),
    },
    DMC {
        number: "830",
        name: "Golden Olive Dark",
        color: (0.553, 0.471, 0.294),
    },
    DMC {
        number: "829",
        name: "Golden Olive Very Dark",
        color: (0.494, 0.42, 0.259),
    },
    DMC {
        number: "613",
        name: "Drab Brown Very Light",
        color: (0.863, 0.769, 0.667),
    },
    DMC {
        number: "612",
        name: "Drab Brown Light",
        color: (0.737, 0.604, 0.471),
    },
    DMC {
        number: "611",
        name: "Drab Brown",
        color: (0.588, 0.463, 0.337),
    },
    DMC {
        number: "610",
        name: "Drab Brown Dark",
        color: (0.475, 0.376, 0.278),
    },
    DMC {
        number: "3047",
        name: "Yellow Beige Light",
        color: (0.906, 0.839, 0.757),
    },
    DMC {
        number: "3046",
        name: "Yellow Beige Medium",
        color: (0.847, 0.737, 0.604),
    },
    DMC {
        number: "3045",
        name: "Yellow Beige Dark",
        color: (0.737, 0.588, 0.416),
    },
    DMC {
        number: "167",
        name: "Yellow Beige Very Dark",
        color: (0.655, 0.486, 0.286),
    },
    DMC {
        number: "746",
        name: "Off White",
        color: (0.988, 0.988, 0.933),
    },
    DMC {
        number: "677",
        name: "Old Gold Very Light",
        color: (0.961, 0.925, 0.796),
    },
    DMC {
        number: "422",
        name: "Hazelnut Brown Light",
        color: (0.776, 0.624, 0.482),
    },
    DMC {
        number: "3828",
        name: "Hazelnut Brown",
        color: (0.718, 0.545, 0.38),
    },
    DMC {
        number: "420",
        name: "Hazelnut Brown Dark",
        color: (0.627, 0.439, 0.259),
    },
    DMC {
        number: "869",
        name: "Hazelnut Brown Very Dark",
        color: (0.514, 0.369, 0.224),
    },
    DMC {
        number: "728",
        name: "Topaz",
        color: (0.894, 0.706, 0.408),
    },
    DMC {
        number: "783",
        name: "Topaz Medium",
        color: (0.808, 0.569, 0.141),
    },
    DMC {
        number: "782",
        name: "Topaz Dark",
        color: (0.682, 0.467, 0.125),
    },
    DMC {
        number: "781",
        name: "Topaz Very Dark",
        color: (0.635, 0.427, 0.125),
    },
    DMC {
        number: "780",
        name: "Topaz Ultra Very Dark",
        color: (0.58, 0.388, 0.102),
    },
    DMC {
        number: "676",
        name: "Old Gold Light",
        color: (0.898, 0.808, 0.592),
    },
    DMC {
        number: "729",
        name: "Old Gold Medium",
        color: (0.816, 0.647, 0.243),
    },
    DMC {
        number: "680",
        name: "Old Gold Dark",
        color: (0.737, 0.553, 0.0549),
    },
    DMC {
        number: "3829",
        name: "Old Gold Vy Dark",
        color: (0.663, 0.51, 0.0157),
    },
    DMC {
        number: "3822",
        name: "Straw Light",
        color: (0.965, 0.863, 0.596),
    },
    DMC {
        number: "3821",
        name: "Straw",
        color: (0.953, 0.808, 0.459),
    },
    DMC {
        number: "3820",
        name: "Straw Dark",
        color: (0.875, 0.714, 0.373),
    },
    DMC {
        number: "3852",
        name: "Straw Very Dark",
        color: (0.804, 0.616, 0.216),
    },
    DMC {
        number: "445",
        name: "Lemon Light",
        color: (1.0, 0.984, 0.545),
    },
    DMC {
        number: "307",
        name: "Lemon",
        color: (0.992, 0.929, 0.329),
    },
    DMC {
        number: "973",
        name: "Canary Bright",
        color: (1.0, 0.89, 0.0),
    },
    DMC {
        number: "444",
        name: "Lemon Dark",
        color: (1.0, 0.839, 0.0),
    },
    DMC {
        number: "3078",
        name: "Golden Yellow Very Light",
        color: (0.992, 0.976, 0.804),
    },
    DMC {
        number: "727",
        name: "Topaz Very Light",
        color: (1.0, 0.945, 0.686),
    },
    DMC {
        number: "726",
        name: "Topaz Light",
        color: (0.992, 0.843, 0.333),
    },
    DMC {
        number: "725",
        name: "Topaz Medium Light",
        color: (1.0, 0.784, 0.251),
    },
    DMC {
        number: "972",
        name: "Canary Deep",
        color: (1.0, 0.71, 0.0824),
    },
    DMC {
        number: "745",
        name: "Yellow Pale Light",
        color: (1.0, 0.914, 0.678),
    },
    DMC {
        number: "744",
        name: "Yellow Pale",
        color: (1.0, 0.906, 0.576),
    },
    DMC {
        number: "743",
        name: "Yellow Medium",
        color: (0.996, 0.827, 0.463),
    },
    DMC {
        number: "742",
        name: "Tangerine Light",
        color: (1.0, 0.749, 0.341),
    },
    DMC {
        number: "741",
        name: "Tangerine Medium",
        color: (1.0, 0.639, 0.169),
    },
    DMC {
        number: "740",
        name: "Tangerine",
        color: (1.0, 0.545, 0.0),
    },
    DMC {
        number: "970",
        name: "Pumpkin Light",
        color: (0.969, 0.545, 0.0745),
    },
    DMC {
        number: "971",
        name: "Pumpkin",
        color: (0.965, 0.498, 0.0),
    },
    DMC {
        number: "947",
        name: "Burnt Orange",
        color: (1.0, 0.482, 0.302),
    },
    DMC {
        number: "946",
        name: "Burnt Orange Medium",
        color: (0.922, 0.388, 0.0275),
    },
    DMC {
        number: "900",
        name: "Burnt Orange Dark",
        color: (0.82, 0.345, 0.0275),
    },
    DMC {
        number: "967",
        name: "Apricot Very Light",
        color: (1.0, 0.871, 0.835),
    },
    DMC {
        number: "3824",
        name: "Apricot Light",
        color: (0.996, 0.804, 0.761),
    },
    DMC {
        number: "3341",
        name: "Apricot",
        color: (0.988, 0.671, 0.596),
    },
    DMC {
        number: "3340",
        name: "Apricot Medium",
        color: (1.0, 0.514, 0.435),
    },
    DMC {
        number: "608",
        name: "Burnt Orange Bright",
        color: (0.992, 0.365, 0.208),
    },
    DMC {
        number: "606",
        name: "Orange Red Bright",
        color: (0.98, 0.196, 0.0118),
    },
    DMC {
        number: "951",
        name: "Tawny Light",
        color: (1.0, 0.886, 0.812),
    },
    DMC {
        number: "3856",
        name: "Mahogany Ultra Very Light",
        color: (1.0, 0.827, 0.71),
    },
    DMC {
        number: "722",
        name: "Orange Spice Light",
        color: (0.969, 0.592, 0.435),
    },
    DMC {
        number: "721",
        name: "Orange Spice Medium",
        color: (0.949, 0.471, 0.259),
    },
    DMC {
        number: "720",
        name: "Orange Spice Dark",
        color: (0.898, 0.361, 0.122),
    },
    DMC {
        number: "3825",
        name: "Pumpkin Pale",
        color: (0.992, 0.741, 0.588),
    },
    DMC {
        number: "922",
        name: "Copper Light",
        color: (0.886, 0.451, 0.137),
    },
    DMC {
        number: "921",
        name: "Copper",
        color: (0.776, 0.384, 0.0941),
    },
    DMC {
        number: "920",
        name: "Copper Medium",
        color: (0.675, 0.329, 0.0784),
    },
    DMC {
        number: "919",
        name: "Red Copper",
        color: (0.651, 0.271, 0.0627),
    },
    DMC {
        number: "918",
        name: "Red Copper Dark",
        color: (0.51, 0.204, 0.0392),
    },
    DMC {
        number: "3770",
        name: "Tawny Vy Light",
        color: (1.0, 0.933, 0.89),
    },
    DMC {
        number: "945",
        name: "Tawny",
        color: (0.984, 0.835, 0.733),
    },
    DMC {
        number: "402",
        name: "Mahogany Very Light",
        color: (0.969, 0.655, 0.467),
    },
    DMC {
        number: "3776",
        name: "Mahogany Light",
        color: (0.812, 0.475, 0.224),
    },
    DMC {
        number: "301",
        name: "Mahogany Medium",
        color: (0.702, 0.373, 0.169),
    },
    DMC {
        number: "400",
        name: "Mahogany Dark",
        color: (0.561, 0.263, 0.0588),
    },
    DMC {
        number: "300",
        name: "Mahogany Very Dark",
        color: (0.435, 0.184, 0.0),
    },
    DMC {
        number: "3823",
        name: "Yellow Ultra Pale",
        color: (1.0, 0.992, 0.89),
    },
    DMC {
        number: "3855",
        name: "Autumn Gold Light",
        color: (0.98, 0.827, 0.588),
    },
    DMC {
        number: "3854",
        name: "Autumn Gold Medium",
        color: (0.949, 0.686, 0.408),
    },
    DMC {
        number: "3853",
        name: "Autumn Gold Dark",
        color: (0.949, 0.592, 0.275),
    },
    DMC {
        number: "3827",
        name: "Golden Brown Pale",
        color: (0.969, 0.733, 0.467),
    },
    DMC {
        number: "977",
        name: "Golden Brown Light",
        color: (0.863, 0.612, 0.337),
    },
    DMC {
        number: "976",
        name: "Golden Brown Medium",
        color: (0.761, 0.506, 0.259),
    },
    DMC {
        number: "3826",
        name: "Golden Brown",
        color: (0.678, 0.447, 0.224),
    },
    DMC {
        number: "975",
        name: "Golden Brown Dark",
        color: (0.569, 0.31, 0.0706),
    },
    DMC {
        number: "948",
        name: "Peach Very Light",
        color: (0.996, 0.906, 0.855),
    },
    DMC {
        number: "754",
        name: "Peach Light",
        color: (0.969, 0.796, 0.749),
    },
    DMC {
        number: "3771",
        name: "Terra Cotta Ultra Very Light",
        color: (0.957, 0.733, 0.663),
    },
    DMC {
        number: "758",
        name: "Terra Cotta Very Light",
        color: (0.933, 0.667, 0.608),
    },
    DMC {
        number: "3778",
        name: "Terra Cotta Light",
        color: (0.851, 0.537, 0.471),
    },
    DMC {
        number: "356",
        name: "Terra Cotta Medium",
        color: (0.773, 0.416, 0.357),
    },
    DMC {
        number: "3830",
        name: "Terra Cotta",
        color: (0.737, 0.333, 0.267),
    },
    DMC {
        number: "355",
        name: "Terra Cotta Dark",
        color: (0.596, 0.267, 0.212),
    },
    DMC {
        number: "3777",
        name: "Terra Cotta Very Dark",
        color: (0.525, 0.188, 0.133),
    },
    DMC {
        number: "3779",
        name: "Rosewood Ultra Very Light",
        color: (0.973, 0.792, 0.784),
    },
    DMC {
        number: "3859",
        name: "Rosewood Light",
        color: (0.729, 0.545, 0.486),
    },
    DMC {
        number: "3858",
        name: "Rosewood Medium",
        color: (0.588, 0.29, 0.247),
    },
    DMC {
        number: "3857",
        name: "Rosewood Dark",
        color: (0.408, 0.145, 0.102),
    },
    DMC {
        number: "3774",
        name: "Desert Sand Very Light",
        color: (0.953, 0.882, 0.843),
    },
    DMC {
        number: "950",
        name: "Desert Sand Light",
        color: (0.933, 0.827, 0.769),
    },
    DMC {
        number: "3064",
        name: "Desert Sand",
        color: (0.769, 0.557, 0.439),
    },
    DMC {
        number: "407",
        name: "Desert Sand Medium",
        color: (0.733, 0.506, 0.38),
    },
    DMC {
        number: "3773",
        name: "Desert Sand Dark",
        color: (0.714, 0.459, 0.322),
    },
    DMC {
        number: "3772",
        name: "Desert Sand Very Dark",
        color: (0.627, 0.424, 0.314),
    },
    DMC {
        number: "632",
        name: "Desert Sand Ultra Very Dark",
        color: (0.529, 0.333, 0.224),
    },
    DMC {
        number: "453",
        name: "Shell Gray Light",
        color: (0.843, 0.808, 0.796),
    },
    DMC {
        number: "452",
        name: "Shell Gray Medium",
        color: (0.753, 0.702, 0.682),
    },
    DMC {
        number: "451",
        name: "Shell Gray Dark",
        color: (0.569, 0.482, 0.451),
    },
    DMC {
        number: "3861",
        name: "Cocoa Light",
        color: (0.651, 0.533, 0.506),
    },
    DMC {
        number: "3860",
        name: "Cocoa",
        color: (0.49, 0.365, 0.341),
    },
    DMC {
        number: "779",
        name: "Cocoa Dark",
        color: (0.384, 0.294, 0.271),
    },
    DMC {
        number: "712",
        name: "Cream",
        color: (1.0, 0.984, 0.937),
    },
    DMC {
        number: "739",
        name: "Tan Ultra Very Light",
        color: (0.973, 0.894, 0.784),
    },
    DMC {
        number: "738",
        name: "Tan Very Light",
        color: (0.925, 0.8, 0.62),
    },
    DMC {
        number: "437",
        name: "Tan Light",
        color: (0.894, 0.733, 0.557),
    },
    DMC {
        number: "436",
        name: "Tan",
        color: (0.796, 0.565, 0.318),
    },
    DMC {
        number: "435",
        name: "Brown Very Light",
        color: (0.722, 0.467, 0.282),
    },
    DMC {
        number: "434",
        name: "Brown Light",
        color: (0.596, 0.369, 0.2),
    },
    DMC {
        number: "433",
        name: "Brown Medium",
        color: (0.478, 0.271, 0.122),
    },
    DMC {
        number: "801",
        name: "Coffee Brown Dark",
        color: (0.396, 0.224, 0.098),
    },
    DMC {
        number: "898",
        name: "Coffee Brown Very Dark",
        color: (0.286, 0.165, 0.0745),
    },
    DMC {
        number: "938",
        name: "Coffee Brown Ultra Dark",
        color: (0.212, 0.122, 0.0549),
    },
    DMC {
        number: "3371",
        name: "Black Brown",
        color: (0.118, 0.0667, 0.0314),
    },
    DMC {
        number: "543",
        name: "Beige Brown Ultra Very Light",
        color: (0.949, 0.89, 0.808),
    },
    DMC {
        number: "3864",
        name: "Mocha Beige Light",
        color: (0.796, 0.714, 0.612),
    },
    DMC {
        number: "3863",
        name: "Mocha Beige Medium",
        color: (0.643, 0.514, 0.361),
    },
    DMC {
        number: "3862",
        name: "Mocha Beige Dark",
        color: (0.541, 0.431, 0.306),
    },
    DMC {
        number: "3031",
        name: "Mocha Brown Very Dark",
        color: (0.294, 0.235, 0.165),
    },
    DMC {
        number: "B5200",
        name: "Snow White",
        color: (1.0, 1.0, 1.0),
    },
    DMC {
        number: "White",
        name: "White",
        color: (0.988, 0.984, 0.973),
    },
    DMC {
        number: "3865",
        name: "Winter White",
        color: (0.976, 0.969, 0.945),
    },
    DMC {
        number: "Ecru",
        name: "Ecru",
        color: (0.941, 0.918, 0.855),
    },
    DMC {
        number: "822",
        name: "Beige Gray Light",
        color: (0.906, 0.886, 0.827),
    },
    DMC {
        number: "644",
        name: "Beige Gray Medium",
        color: (0.867, 0.847, 0.796),
    },
    DMC {
        number: "642",
        name: "Beige Gray Dark",
        color: (0.643, 0.596, 0.471),
    },
    DMC {
        number: "640",
        name: "Beige Gray Very Dark",
        color: (0.522, 0.482, 0.38),
    },
    DMC {
        number: "3787",
        name: "Brown Gray Dark",
        color: (0.384, 0.365, 0.314),
    },
    DMC {
        number: "3021",
        name: "Brown Gray Very Dark",
        color: (0.31, 0.294, 0.255),
    },
    DMC {
        number: "3024",
        name: "Brown Gray Very Light",
        color: (0.922, 0.918, 0.906),
    },
    DMC {
        number: "3023",
        name: "Brown Gray Light",
        color: (0.694, 0.667, 0.592),
    },
    DMC {
        number: "3022",
        name: "Brown Gray Medium",
        color: (0.557, 0.565, 0.471),
    },
    DMC {
        number: "535",
        name: "Ash Gray Very Light",
        color: (0.388, 0.392, 0.345),
    },
    DMC {
        number: "3033",
        name: "Mocha Brown Very Light",
        color: (0.89, 0.847, 0.8),
    },
    DMC {
        number: "3782",
        name: "Mocha Brown Light",
        color: (0.824, 0.737, 0.651),
    },
    DMC {
        number: "3032",
        name: "Mocha Brown Medium",
        color: (0.702, 0.624, 0.545),
    },
    DMC {
        number: "3790",
        name: "Beige Gray Ultra Dark",
        color: (0.498, 0.416, 0.333),
    },
    DMC {
        number: "3781",
        name: "Mocha Brown Dark",
        color: (0.42, 0.341, 0.263),
    },
    DMC {
        number: "3866",
        name: "Mocha Brown Ultra Very Light",
        color: (0.98, 0.965, 0.941),
    },
    DMC {
        number: "842",
        name: "Beige Brown Very Light",
        color: (0.82, 0.729, 0.631),
    },
    DMC {
        number: "841",
        name: "Beige Brown Light",
        color: (0.714, 0.608, 0.494),
    },
    DMC {
        number: "840",
        name: "Beige Brown Medium",
        color: (0.604, 0.486, 0.361),
    },
    DMC {
        number: "839",
        name: "Beige Brown Dark",
        color: (0.404, 0.333, 0.255),
    },
    DMC {
        number: "838",
        name: "Beige Brown Very Dark",
        color: (0.349, 0.286, 0.216),
    },
    DMC {
        number: "3072",
        name: "Beaver Gray Very Light",
        color: (0.902, 0.91, 0.91),
    },
    DMC {
        number: "648",
        name: "Beaver Gray Light",
        color: (0.737, 0.706, 0.675),
    },
    DMC {
        number: "647",
        name: "Beaver Gray Medium",
        color: (0.69, 0.651, 0.612),
    },
    DMC {
        number: "646",
        name: "Beaver Gray Dark",
        color: (0.529, 0.49, 0.451),
    },
    DMC {
        number: "645",
        name: "Beaver Gray Very Dark",
        color: (0.431, 0.396, 0.361),
    },
    DMC {
        number: "844",
        name: "Beaver Gray Ultra Dark",
        color: (0.282, 0.282, 0.282),
    },
    DMC {
        number: "762",
        name: "Pearl Gray Very Light",
        color: (0.925, 0.925, 0.925),
    },
    DMC {
        number: "415",
        name: "Pearl Gray",
        color: (0.827, 0.827, 0.839),
    },
    DMC {
        number: "318",
        name: "Steel Gray Light",
        color: (0.671, 0.671, 0.671),
    },
    DMC {
        number: "414",
        name: "Steel Gray Dark",
        color: (0.549, 0.549, 0.549),
    },
    DMC {
        number: "168",
        name: "Pewter Very Light",
        color: (0.82, 0.82, 0.82),
    },
    DMC {
        number: "169",
        name: "Pewter Light",
        color: (0.518, 0.518, 0.518),
    },
    DMC {
        number: "317",
        name: "Pewter Gray",
        color: (0.424, 0.424, 0.424),
    },
    DMC {
        number: "413",
        name: "Pewter Gray Dark",
        color: (0.337, 0.337, 0.337),
    },
    DMC {
        number: "3799",
        name: "Pewter Gray Very Dark",
        color: (0.259, 0.259, 0.259),
    },
    DMC {
        number: "310",
        name: "Black",
        color: (0.0, 0.0, 0.0),
    },
    DMC {
        number: "01",
        name: "White Tin",
        color: (0.89, 0.89, 0.902),
    },
    DMC {
        number: "02",
        name: "Tin",
        color: (0.843, 0.843, 0.847),
    },
    DMC {
        number: "03",
        name: "Tin Medium",
        color: (0.722, 0.722, 0.733),
    },
    DMC {
        number: "04",
        name: "Tin Dark",
        color: (0.682, 0.682, 0.694),
    },
    DMC {
        number: "05",
        name: "Driftwood Light",
        color: (0.89, 0.8, 0.745),
    },
    DMC {
        number: "06",
        name: "Driftwood Medium Light",
        color: (0.863, 0.776, 0.722),
    },
    DMC {
        number: "07",
        name: "Driftwood",
        color: (0.561, 0.482, 0.431),
    },
    DMC {
        number: "08",
        name: "Driftwood Dark",
        color: (0.416, 0.314, 0.275),
    },
    DMC {
        number: "09",
        name: "Cocoa Very Dark",
        color: (0.333, 0.125, 0.0784),
    },
    DMC {
        number: "10",
        name: "Tender Green Very Light",
        color: (0.929, 0.996, 0.851),
    },
    DMC {
        number: "11",
        name: "Tender Green Light",
        color: (0.886, 0.929, 0.71),
    },
    DMC {
        number: "12",
        name: "Tender Green",
        color: (0.804, 0.851, 0.604),
    },
    DMC {
        number: "13",
        name: "Nile Green Medium Light",
        color: (0.749, 0.965, 0.878),
    },
    DMC {
        number: "14",
        name: "Apple Green Pale",
        color: (0.816, 0.984, 0.698),
    },
    DMC {
        number: "15",
        name: "Apple Green",
        color: (0.82, 0.929, 0.643),
    },
    DMC {
        number: "16",
        name: "Chartreuse Light",
        color: (0.788, 0.761, 0.345),
    },
    DMC {
        number: "17",
        name: "Yellow Plum Light",
        color: (0.898, 0.886, 0.447),
    },
    DMC {
        number: "18",
        name: "Yellow Plum",
        color: (0.851, 0.835, 0.427),
    },
    DMC {
        number: "19",
        name: "Autumn Gold medium Light",
        color: (0.969, 0.788, 0.373),
    },
    DMC {
        number: "20",
        name: "Shrimp",
        color: (0.969, 0.686, 0.576),
    },
    DMC {
        number: "21",
        name: "Alizarin Light",
        color: (0.843, 0.6, 0.51),
    },
    DMC {
        number: "22",
        name: "Alizarin",
        color: (0.737, 0.376, 0.306),
    },
    DMC {
        number: "23",
        name: "Apple Blossom",
        color: (0.929, 0.886, 0.929),
    },
    DMC {
        number: "24",
        name: "White Lavender",
        color: (0.878, 0.843, 0.933),
    },
    DMC {
        number: "25",
        name: "Lavender Ultra Light",
        color: (0.855, 0.824, 0.914),
    },
    DMC {
        number: "26",
        name: "Lavender Pale",
        color: (0.843, 0.792, 0.902),
    },
    DMC {
        number: "27",
        name: "White Violet",
        color: (0.941, 0.933, 0.976),
    },
    DMC {
        number: "28",
        name: "Eggplant Medium Light",
        color: (0.565, 0.525, 0.663),
    },
    DMC {
        number: "29",
        name: "Eggplant",
        color: (0.404, 0.251, 0.463),
    },
    DMC {
        number: "30",
        name: "Blueberry Medium Light",
        color: (0.49, 0.467, 0.647),
    },
    DMC {
        number: "31",
        name: "Blueberry",
        color: (0.314, 0.318, 0.553),
    },
    DMC {
        number: "32",
        name: "Blueberry Dark",
        color: (0.302, 0.18, 0.541),
    },
    DMC {
        number: "33",
        name: "Fuschia",
        color: (0.612, 0.349, 0.612),
    },
    DMC {
        number: "34",
        name: "Fuschia Dark",
        color: (0.49, 0.188, 0.392),
    },
    DMC {
        number: "35",
        name: "Fuschia Very Dark",
        color: (0.275, 0.0196, 0.176),
    },
];

lazy_static! {
    pub static ref LOOKUP: HashMap<&'static str, &'static DMC> = {
        let mut map = HashMap::new();
        for dmc in COLORS {
            map.insert(dmc.number, dmc);
        }
        map
    };
}
